# Generated by Django 4.2.11 on 2024-07-27 00:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0006_endpoints_baseline_datetime"),
    ]

    operations = [
        migrations.AlterField(
            model_name="endpoints",
            name="endpoint_label",
            field=models.CharField(max_length=25, null=True),
        ),
        migrations.AlterField(
            model_name="endpoints",
            name="fasting",
            field=models.CharField(max_length=10, null=True),
        ),
        migrations.AlterField(
            model_name="endpoints",
            name="fbg_datetime",
            field=models.DateTimeField(null=True),
        ),
        migrations.AlterField(
            model_name="endpoints",
            name="fbg_value",
            field=models.FloatField(null=True),
        ),
        migrations.AlterField(
            model_name="endpoints",
            name="ogtt_value",
            field=models.FloatField(null=True),
        ),
        migrations.AlterField(
            model_name="endpoints",
            name="visit_code",
            field=models.IntegerField(null=True),
        ),
    ]
