# Generated by Django 3.2.11 on 2022-03-07 16:29

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_ae", "0008_auto_20211011_1657"),
    ]

    operations = [
        migrations.AlterField(
            model_name="deathreport",
            name="death_location",
            field=models.CharField(
                choices=[
                    ("home", "At home"),
                    ("hospital_clinic", "Hospital/clinic"),
                    ("elsewhere", "Elsewhere"),
                ],
                max_length=50,
                verbose_name="Where did the participant die?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldeathreport",
            name="death_location",
            field=models.CharField(
                choices=[
                    ("home", "At home"),
                    ("hospital_clinic", "Hospital/clinic"),
                    ("elsewhere", "Elsewhere"),
                ],
                max_length=50,
                verbose_name="Where did the participant die?",
            ),
        ),
    ]
