# Generated by Django 5.1 on 2024-09-11 00:52
from django.apps import apps as django_apps
from django.db import migrations


def update_report_datetime_as_none(apps, schema_editor):
    model_cls = django_apps.get_model("meta_pharmacy.substitutions")
    model_cls.objects.update(report_datetime=None)


class Migration(migrations.Migration):

    dependencies = [
        ("meta_pharmacy", "0004_alter_historicalsubstitutions_report_datetime_and_more"),
    ]

    operations = [migrations.RunPython(update_report_datetime_as_none)]
