# Generated by Django 4.2.11 on 2024-05-15 17:34

import uuid

import _socket
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_revision.revision_field
import edc_crf.model_mixins.crf_status_model_mixin
import edc_model.validators.date
import edc_protocol.validators
import edc_utils.date
import edc_visit_tracking.managers
import simple_history.models
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("sites", "0002_alter_domain_unique"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("meta_subject", "0185_alter_bloodresultsins_fasting_duration_str_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="healtheconomicsupdate",
            name="singleton_field",
            field=models.CharField(
                editable=False,
                help_text="auto updated for unique constraint",
                max_length=50,
                null=True,
                unique=True,
                verbose_name="subject identifier",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicsupdate",
            name="singleton_field",
            field=models.CharField(
                db_index=True,
                editable=False,
                help_text="auto updated for unique constraint",
                max_length=50,
                null=True,
                verbose_name="subject identifier",
            ),
        ),
    ]
