# Generated by Django 5.1.2 on 2024-10-10 04:23

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("edc_pharmacy", "0023_remove_rx_edc_pharmac_modifie_986021_idx_and_more"),
        ("meta_pharmacy", "0006_lotnumber_label"),
    ]

    operations = [
        migrations.AddField(
            model_name="lotnumber",
            name="medication",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_pharmacy.medication",
            ),
        ),
    ]
