# Generated by Django 4.2.10 on 2024-03-07 23:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_prn", "0055_alter_endofstudy_site_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="endofstudy",
            name="clinical_withdrawal_reason",
            field=models.CharField(
                choices=[
                    ("kidney_disease", "Development of chronic kidney disease"),
                    ("liver_disease", "Development of chronic liver disease"),
                    (
                        "intercurrent_illness",
                        "Intercurrent illness which prevents further treatment",
                    ),
                    ("investigator_decision", "Investigator decision (specify below)"),
                    (
                        "OTHER",
                        "Other condition that justifies the discontinuation of treatment in the clinician's opinion (specify below)",
                    ),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="If the patient was withdrawn on CLINICAL grounds, please specify PRIMARY reason",
            ),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="clinical_withdrawal_reason",
            field=models.CharField(
                choices=[
                    ("kidney_disease", "Development of chronic kidney disease"),
                    ("liver_disease", "Development of chronic liver disease"),
                    (
                        "intercurrent_illness",
                        "Intercurrent illness which prevents further treatment",
                    ),
                    ("investigator_decision", "Investigator decision (specify below)"),
                    (
                        "OTHER",
                        "Other condition that justifies the discontinuation of treatment in the clinician's opinion (specify below)",
                    ),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=25,
                verbose_name="If the patient was withdrawn on CLINICAL grounds, please specify PRIMARY reason",
            ),
        ),
        migrations.AlterField(
            model_name="historicaloffstudymedication",
            name="reason",
            field=models.CharField(
                choices=[
                    ("pregnancy", "Pregnancy"),
                    ("sae", "Participant is experiencing a serious adverse event"),
                    (
                        "clinician",
                        "Other condition that justifies discontinuation of treatment in the clinician's opinion (specify below)",
                    ),
                    ("investigator", " Investigator decision"),
                    ("patient", "Patient decision"),
                    ("OTHER", "Other reason (specify below)"),
                ],
                max_length=25,
                verbose_name="Reason for stopping study medication",
            ),
        ),
        migrations.AlterField(
            model_name="offstudymedication",
            name="reason",
            field=models.CharField(
                choices=[
                    ("pregnancy", "Pregnancy"),
                    ("sae", "Participant is experiencing a serious adverse event"),
                    (
                        "clinician",
                        "Other condition that justifies discontinuation of treatment in the clinician's opinion (specify below)",
                    ),
                    ("investigator", " Investigator decision"),
                    ("patient", "Patient decision"),
                    ("OTHER", "Other reason (specify below)"),
                ],
                max_length=25,
                verbose_name="Reason for stopping study medication",
            ),
        ),
    ]
