# Generated by Django 5.1 on 2024-10-07 22:02

import edc_utils.date
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0049_auto_20240911_0327"),
    ]

    operations = [
        migrations.AlterField(
            model_name="endpoints",
            name="created",
            field=models.DateTimeField(default=edc_utils.date.get_utcnow),
        ),
    ]
