# Generated by Django 4.2.11 on 2024-05-15 23:47

from django.db import migrations
from edc_constants.constants import YES


def update_fasting_duration(apps, schema_editor):
    model_cls = apps.get_model("meta_subject.glucosefbg")
    model_cls.objects.filter(fasting_duration_estimated=YES).update(fasting_duration_str="8h")


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0198_alter_glucosefbg_fasting_duration_estimated_and_more"),
    ]

    operations = [migrations.RunPython(update_fasting_duration)]
